/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.test;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.script.service.ScriptService;

/**
 * A script service that provides a sleep method for testing purposes.
 *
 * @version $Id: 8af739c6483767d1c315478b23642bebd94d55d8 $
 */
@Component
@Singleton
@Named("sleep")
public class SleepScriptService implements ScriptService
{
    /**
     * Sleep for a given number of seconds.
     *
     * @param seconds the number of seconds to sleep
     */
    public void sleepInSolr(long seconds)
    {
        // Check if we're in the Solr indexing thread.
        if (Thread.currentThread().getName().equals("XWiki Solr index thread")) {
            try {
                Thread.sleep(seconds * 1000);
            } catch (InterruptedException e) {
                Thread.currentThread().interrupt();
            }
        }
    }
}
